@@ -23,7 +23,7 @@
  * 
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: pfsoutimgmagick.cpp,v 1.6 2008/10/22 22:20:29 rafm Exp $
+ * $Id: pfsoutimgmagick.cpp,v 1.7 2011/03/15 08:47:24 rafm Exp $
  */
 
 #include <config.h>
@@ -142,6 +142,8 @@ void writeFrames( int argc, char* argv[] )
     }
 
     alpha = frame->getChannel( "ALPHA" );
+    if( alpha == NULL )
+      alpha = frame->getChannel( "A" );
         
     const char* luminanceTag = frame->getTags()->getString("LUMINANCE");
     if( luminanceTag!=NULL && strcmp(luminanceTag,"ABSOLUTE")==0 )
