@@ -22,7 +22,7 @@
  *
  * @author Miloslaw Smyk, <thorgal@wfmh.org.pl>
  *
- * $Id: pfspanoramic.cpp,v 1.3 2008/07/29 16:14:30 rafm Exp $
+ * $Id: pfspanoramic.cpp,v 1.4 2010/02/18 11:27:03 rafm Exp $
  */
 
 #include <map>
@@ -191,7 +191,7 @@ class ProjectionFactory
       singleton.projections[ string( name ) ] = ptr;
     }
 
-    static Projection *getProjection(const char *name)
+    static Projection *getProjection(char *name)
     {
       char *opts;
       
