@@ -1,10 +1,14 @@
 function Y = pfs_read_luminance( fileName )
-% Read hdr image file (formats accepted by pfsin) and return
-% luminance channel Y.
+%PFS_READ_LUMINANCE read image file and return luminance channel Y.
 %
-%  Y = hdr_read_luminance( fileName )
-
-Y = -1;
+%  Y = PFS_READ_LUMINANCE( file_name )
+%
+% PFS_READ_LUMINANCE accepts all formats recognized by the shell "pfsin"
+% command.
+%
+% See also: PFS_READ_IMAGE, PFS_READ_LUMINANCE, PFS_READ_XYZ, PFS_WRITE_IMAGE.
+%
+% Copyright 2009 Rafal Mantiuk
 
   % Check if file exists
   fid = fopen( fileName, 'r' );
@@ -14,7 +18,8 @@ Y = -1;
   fclose( fid );
      
 %  try
-    fid = pfspopen( sprintf( '%spfsin ''%s''%s', pfs_shell(), fileName, pfs_shell( 1 ) ), 'r' );
+    cmd = sprintf( '%spfsin ''%s''%s', pfs_shell(), fileName, pfs_shell( 1 ) );
+    fid = pfspopen( cmd, 'r' );
     pin = pfsopen( fid );
     pin = pfsget( pin );
     Y = pin.channels.Y;  
