@@ -1,13 +1,19 @@
 function [varargout] = pfs_read_rgb( fileName )
-% Read hdr image file (formats accepted by pfsin) and return R, G,
-% and B color channels or a single 3D matrix.
+%PFS_READ_RGB Read image file and return R, G, and B color channels or a single 3D matrix.
 %
-% [R G B] = pfs_read_rgb( fileName )
-% img = pfs_read_rgb( fileName )
+% [R G B] = PFS_READ_RGB( file_name )
+% IMG = PFS_READ_RGB( file_name)
 %
 % R, G, B - red, green and blue color channels, given as linear response
 % img - 3D matrix image, where img(:,:,1:3) represents red, blue and green
 %       color channels
+%
+% PFS_READ_RGB accepts all formats recognized by the shell "pfsin"
+% command.
+%
+% See also: PFS_READ_IMAGE, PFS_READ_LUMINANCE, PFS_READ_XYZ, PFS_WRITE_IMAGE.
+%
+% Copyright 2009 Rafal Mantiuk
 
   %Check if file exists
   fid = fopen( fileName, 'rb' );
@@ -20,7 +26,15 @@ function [varargout] = pfs_read_rgb( fileName )
   pin = pfsopen( fid );
   pin = pfsget( pin );
 
-  [R G B] = pfs_transform_colorspace( 'XYZ', pin.channels.X, pin.channels.Y, pin.channels.Z, 'RGB' );    
+  if( isfield( pin.channels, 'X' ) && isfield( pin.channels, 'Z' ) )
+      [R G B] = pfs_transform_colorspace( 'XYZ', pin.channels.X, pin.channels.Y, pin.channels.Z, 'RGB' );
+  elseif( isfield( pin.channels, 'Y' ) )
+      R = pin.channels.Y;
+      G = pin.channels.Y;
+      B = pin.channels.Y;
+  else
+      error( 'Color channels missing in the pfs frame' );
+  end
   
   if( nargout == 3 )
       varargout{1} = R;
