@@ -22,13 +22,14 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: pfs_transform_colorspace.cpp,v 1.8 2008/10/02 22:30:51 rafm Exp $
+ * $Id: pfs_transform_colorspace.cpp,v 1.9 2010/06/05 18:24:24 rafm Exp $
  */
 
 #include "compatibility.h"
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <fcntl.h>
 #include <sys/stat.h>
 
@@ -112,11 +113,11 @@ void mexFunction(int nlhs, mxArray *plhs[],
 
 static pfs::ColorSpace findColorSpace( const char *name )
 {
-    if( !stricmp( name, "XYZ" ) ) return pfs::CS_XYZ;
-    else if( !stricmp( name, "RGB" ) ) return pfs::CS_RGB;
-    else if( !stricmp( name, "SRGB" ) ) return pfs::CS_SRGB;
-    else if( !stricmp( name, "YUV" ) ) return pfs::CS_YUV;
-    else if( !stricmp( name, "YXY" ) ) return pfs::CS_Yxy;
+    if( !strcasecmp( name, "XYZ" ) ) return pfs::CS_XYZ;
+    else if( !strcasecmp( name, "RGB" ) ) return pfs::CS_RGB;
+    else if( !strcasecmp( name, "SRGB" ) ) return pfs::CS_SRGB;
+    else if( !strcasecmp( name, "YUV" ) ) return pfs::CS_YUV;
+    else if( !strcasecmp( name, "YXY" ) ) return pfs::CS_Yxy;
 
     throw pfs::Exception( "Not recognized color space" );
 }
