@@ -57,6 +57,17 @@ function pfsview( varargin )
       elseif( length(m_size) == 3 && m_size(3)==3 )
           % Color channels
           [channels.X channels.Y channels.Z] = pfs_transform_colorspace( 'RGB', single(varargin{i}), 'XYZ' );
+      elseif( length(m_size) == 3 && m_size(3)<10 )
+          matrix_name = inputname( i );
+          if( isempty( matrix_name ) )
+              ch_name = sprintf( 'matrix_%d', n );
+              n = n+1;
+          else
+              ch_name = matrix_name;
+          end
+          for j=1:m_size(3)
+              channels.( sprintf( '%s_%d', ch_name, j ) ) = single( varargin{i}(:,:,j) );
+          end
       else
           error( [ 'Cannot display matrix of the size [' num2str( m_size ) ']' ] );
       end
