@@ -22,19 +22,19 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: main.h,v 1.6 2008/10/02 22:42:01 rafm Exp $
+ * $Id: main.h,v 1.11 2011/03/21 16:09:16 rafm Exp $
  */
 
 #ifndef MAIN_H
 #define MAIN_H
 
 #include <qapplication.h>
-#include <qmainwindow.h>
 #include <qmessagebox.h>
 #include <qlayout.h>
-#include <qpopupmenu.h>
 #include <qmenubar.h>
 #include <qsplitter.h>
+#include <QLabel>
+#include <QMainWindow>
 
 #include <list>
 
@@ -45,7 +45,7 @@
 class LuminanceRangeWidget;
 class QComboBox;
 
-class pfs::Frame;
+//class pfs::Frame;
 
 
 enum ColorCoord { CC_RGB = 0, CC_XYZ, CC_Yupvp, CC_Yxy, CC_COUNT
@@ -57,10 +57,9 @@ public:
     PFSViewMainWin( float window_min, float window_max );
     
 public slots:
-    void changeClippingMethod( int clippingMethod );
+//    void changeClippingMethod( int clippingMethod );
     void updatePointerValue();
     void updateRangeWindow();
-    void updateViewSize();
     void updateChannelSelection();
     void setChannelSelection( int selectedChannel );
     void updateZoomValue();
@@ -68,28 +67,21 @@ public slots:
     void gotoPreviousFrame();
     void saveImage();
     void copyImage();
-    void setInfNaNTreatment( int method );
-    void setNegativeTreatment( int method );
     void setLumMappingMethod( int method );
-    void setColorCoord( int method );
+    void setLumMappingMethod( QAction *action );
+    void setColorCoord( QAction *action );
     void showAboutdialog();
+    void updateViewSize();    
 private:
     void setFrame( pfs::Frame *frame );
 
-    int clippingMethodMI[CLIP_COUNT];
-    int infNaNMI[2];
-    int negativeMI[NEGATIVE_COUNT];
+    QAction *mappingAct[6];    
     
-    QPopupMenu *viewMenu;
-    QPopupMenu *infnanMenu, *negativeMenu;
-    QPopupMenu *colorCoordMenu;
-    QPopupMenu *colorClipMenu;
     QLabel *pointerPosAndVal, *zoomValue, *exposureValue;
     PFSViewWidget *pfsView;
     LuminanceRangeWidget *lumRange;
     QComboBox *channelSelection;
     QComboBox *mappingMethodCB;
-    QStatusBar *statusBar;
     ColorCoord colorCoord;
 
     bool readNextFrame();
@@ -97,15 +89,15 @@ private:
     void updateMenuEnable( );
     
     std::list<pfs::Frame*> frameList;
-    std::list<pfs::Frame*>::iterator currentFrame;    
+    std::list<pfs::Frame*>::iterator currentFrame;
     
 public:
-
+    
     PFSViewWidget *getPFSViewWidget() 
       {
         return pfsView;
       }
-    
+
 };
 
 #endif
