@@ -22,7 +22,7 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: pfsview_widget.cpp,v 1.16 2009/05/11 18:05:21 rafm Exp $
+ * $Id: pfsview_widget.cpp,v 1.21 2011/04/30 14:01:17 rafm Exp $
  */
 
 #include <config.h>
@@ -35,6 +35,11 @@
 #include <qcolor.h>
 #include <qcursor.h>
 #include <qapplication.h>
+#include <QMouseEvent>
+#include <QEvent>
+#include <QApplication>
+#include <QDesktopWidget>
+#include <QList>
 
 //#include <algorithm>
 
@@ -68,16 +73,43 @@ inline int clamp( int val, int min, int max )
 
 const char* COLOR_CHANNELS = "Color";
 
-PFSViewWidget::PFSViewWidget( QWidget *parent, const char *name ) :
-  QScrollView( parent, name, WRepaintNoErase ), image( NULL ),
+PFSViewWidgetArea::PFSViewWidgetArea( QWidget *parent ) :
+  QScrollArea( parent )
+{
+  PFSViewWidget *pfsview = new PFSViewWidget( this );
+  setWidget( pfsview );
+  setWidgetResizable( true );
+  
+  setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred );  
+}
+
+QSize PFSViewWidgetArea::sizeHint() const
+{
+  QSize sz = widget()->sizeHint();
+//  printf( "widget: %d %d\n", sz.width(), sz.height() );
+  sz += QSize( frameWidth()*2, frameWidth()*2 );  
+//  printf( "area: %d %d\n", sz.width(), sz.height() );
+  return sz;
+}
+
+
+PFSViewWidget::PFSViewWidget( QWidget *parent ) :
+  QWidget( parent ), image( NULL ),
   minValue( 1.f ), maxValue( 100.f ), zoom( 1.f ),
   mappingMethod( MAP_GAMMA2_2 ), visibleChannel( COLOR_CHANNELS ),
   negativeTreatment( NEGATIVE_BLACK ), infNaNTreatment( INFNAN_MARK_AS_RED ),
   updateMappingRequested( true ), clippingMethod(CLIP_SIMPLE)
 {
-  viewport()->setMouseTracking( true );
-  viewport()->setCursor( QCursor( crossCursor ) );
-  setResizePolicy( Manual );
+
+  setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
+  
+  
+  setMouseTracking( true );
+  setCursor( QCursor( Qt::CrossCursor ) );
+
+//name, Qt::WNoAutoErase
+  
+//  setResizePolicy( Manual );
   
   pfsFrame = NULL;
   workArea[0] = workArea[1] = workArea[2] = NULL;
@@ -131,26 +163,34 @@ void PFSViewWidget::setFrame( pfs::Frame *frame )
   setPointer();  
 }
 
-void PFSViewWidget::drawContents( QPainter * p, int clipx, int clipy, int clipw, int cliph )
+//void PFSViewWidget::drawContents( QPainter * p, int clipx, int clipy, int clipw, int cliph )
+
+void PFSViewWidget::paintEvent( QPaintEvent *event )
 {
   assert( pfsFrame != NULL );
 
+  QRect clip = event->rect();
+  int clipx = clip.x();
+  int clipy = clip.y();
+  int clipw = clip.width();
+  int cliph = clip.height();
+  
+  
   if( updateMappingRequested )
     updateMapping();
-
   
-//  QPainter p( this );
+  QPainter p( this );
 //  if( image != NULL ) p->drawImage( 0, 0, *image );
   if( image != NULL ) {
-    p->drawImage( clipx, clipy, *image, clipx, clipy, clipw, cliph );
+      p.drawImage( clipx, clipy, *image, clipx, clipy, clipw, cliph );
 
     //Erase area outside image
     if( clipx+clipw > image->width() )
-      p->eraseRect( image->width(), 0, clipx+clipw - image->width(), image->height() );
+      p.eraseRect( image->width(), 0, clipx+clipw - image->width(), image->height() );
     if( clipy+cliph > image->height() )
-      p->eraseRect( 0, image->height(), image->width(), clipy+cliph - image->height() );
+      p.eraseRect( 0, image->height(), image->width(), clipy+cliph - image->height() );
     if( clipx+clipw > image->width() && clipy+cliph > image->height() )
-      p->eraseRect( image->width(), image->height(),
+      p.eraseRect( image->width(), image->height(),
         clipx+clipw - image->width(), clipy+cliph - image->height() );
     
   }
@@ -472,7 +512,8 @@ void PFSViewWidget::postUpdateMapping()
 {
   updateMappingRequested = true;
 
-  updateContents( 0, 0, image->width(), image->height() );
+  update( 0, 0, image->width(), image->height() );
+  //updateContents( 0, 0, image->width(), image->height() );
 }
 
 
@@ -480,7 +521,7 @@ void PFSViewWidget::updateMapping()
 { 
   assert( image != NULL );
 
-  QApplication::setOverrideCursor( Qt::waitCursor );
+  QApplication::setOverrideCursor( Qt::WaitCursor );
   
   if( visibleChannel == COLOR_CHANNELS ) {
     
@@ -505,7 +546,7 @@ void PFSViewWidget::updateZoom()
 {
   assert( pfsFrame != NULL );
 
-  QApplication::setOverrideCursor( Qt::waitCursor );
+  QApplication::setOverrideCursor( Qt::WaitCursor );
   
   if( visibleChannel == COLOR_CHANNELS ) {
     pfs::Channel *X, *Y, *Z;
@@ -520,13 +561,16 @@ void PFSViewWidget::updateZoom()
   int zoomedHeight = max( workArea[0]->getRows(), (int)((float)(pfsFrame->getHeight())*zoom) );    
   
   if( image != NULL ) delete image;
-  image = new QImage( zoomedWidth, zoomedHeight, 32 );
+  image = new QImage( zoomedWidth, zoomedHeight, QImage::Format_RGB32 );
   assert( image != NULL );
   
   postUpdateMapping();
 
-  resizeContents( zoomedWidth, zoomedHeight );
-  updateContents( 0, 0, zoomedWidth, zoomedHeight );
+  resize( zoomedWidth, zoomedHeight );
+  
+//  resizeContents( zoomedWidth, zoomedHeight );
+//  updateContents( 0, 0, zoomedWidth, zoomedHeight );
+  update( 0, 0, zoomedWidth, zoomedHeight );
 
   QApplication::restoreOverrideCursor();  
 }
@@ -534,28 +578,31 @@ void PFSViewWidget::updateZoom()
 QSize PFSViewWidget::sizeHint() const
 {
   if( pfsFrame != NULL ) 
-    return QSize( (int)((float)pfsFrame->getWidth()*zoom) + 2 * frameWidth(), (int)((float)pfsFrame->getHeight()*zoom) + 2 * frameWidth() );
-//    return QSize( pfsFrame->getWidth() + 2 * frameWidth(), pfsFrame->getHeight() + 2 * frameWidth() );
+    return QSize( (int)((float)pfsFrame->getWidth()*zoom), (int)((float)pfsFrame->getHeight()*zoom)  );
+
+//    return QSize( (int)((float)pfsFrame->getWidth()*zoom) + 2 * frameWidth(), (int)((float)pfsFrame->getHeight()*zoom) + 2 * frameWidth() );
+
+  //    return QSize( pfsFrame->getWidth() + 2 * frameWidth(), pfsFrame->getHeight() + 2 * frameWidth() );
   else return QWidget::sizeHint();
 }
 
 // ======================= Events ===========================
 
-void PFSViewWidget::setRGBClippingMethod( int method )
+void PFSViewWidget::setRGBClippingMethod( QAction *action )
 {
-  clippingMethod = (RGBClippingMethod)method;
+  clippingMethod = (RGBClippingMethod)action->data().toUInt();
   postUpdateMapping();
 }
 
-void PFSViewWidget::setInfNaNTreatment( int method )
+void PFSViewWidget::setInfNaNTreatment( QAction *action )
 {
-  infNaNTreatment = (InfNaNTreatment)method;
+  infNaNTreatment = (InfNaNTreatment)action->data().toUInt();
   postUpdateMapping();
 }
 
-void PFSViewWidget::setNegativeTreatment( int method )
+void PFSViewWidget::setNegativeTreatment( QAction *action )
 {
-  negativeTreatment = (NegativeTreatment)method;
+  negativeTreatment = (NegativeTreatment)action->data().toUInt();
   postUpdateMapping();
 }
 
@@ -598,12 +645,12 @@ void PFSViewWidget::setRangeWindow( float min, float max )
 
 // ===================== Mouse interaction =========================
 
-void PFSViewWidget::viewportMouseMoveEvent( QMouseEvent *mouseEvent )
+void PFSViewWidget::mouseMoveEvent( QMouseEvent *mouseEvent )
 {
   assert( pfsFrame != NULL );
 
-  setPointer( (int)((float)(mouseEvent->x()+contentsX()) / zoom),
-    (int)((float)(mouseEvent->y()+contentsY()) / zoom) );  
+  setPointer( (int)((float)mouseEvent->x() / zoom),
+    (int)((float)mouseEvent->y() / zoom) );  
 }
 
 void PFSViewWidget::setPointer( int x, int y )
@@ -680,25 +727,18 @@ const pfs::Array2D *PFSViewWidget::getPrimaryChannel()
   
 }
 
-const QArray<const char*> PFSViewWidget::getChannels()
+const QList<const char*> PFSViewWidget::getChannels()
 {
   assert( pfsFrame != NULL );
+  
+  QList<const char*> chArray;
 
-  int count = 0;
   pfs::ChannelIterator *it = pfsFrame->getChannels();
+  it = pfsFrame->getChannels();
   while( it->hasNext() )
   {
     pfs::Channel *ch = it->getNext();
-    count++;
-  }
-  
-  QArray<const char*> chArray( count );
-
-  it = pfsFrame->getChannels();
-  for( int c = 0; c < count; c++ )
-  {
-    pfs::Channel *ch = it->getNext();
-    chArray[c] = ch->getName();
+    chArray.push_back(ch->getName());
   }
 
   return chArray;
